logo

package module
v0.0.3 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jun 24, 2026 License: MIT Imports: 9 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Image

func Image() image.Image

func Render

func Render() string

func RenderImage

func RenderImage(r io.Reader) (string, error)

RenderImage reads an image from r and returns Kitty protocol output.

func RenderImageResized added in v0.0.2

func RenderImageResized(r io.Reader, width, height int) (string, error)

RenderImageResized reads an image from r, resizes it to the given dimensions, and returns Kitty protocol output.

func RenderWithSize added in v0.0.2

func RenderWithSize(width, height int) string

Types

This section is empty.

Directories

Path Synopsis
cmd
logo command

Jump to